@@ -54,14 +54,15 @@ ASCOV_JADE <- function(sdf,supp=NULL,A=NULL,...)
                 diag(p)[,i]),tcrossprod(diag(p)[,i],diag(p)[,i]))    
    } 
   }
-    
+  
+  EMD<-sum(diag(ASCOV)-diag(ASCOV)*as.vector(diag(p)))  
   W<-crossprod(t(P),solve(A))
   W<-crossprod(diag(sign(rowMeans(W))),W)
   A<-solve(W)
   COV_A<-crossprod(t(tcrossprod(kronecker(diag(p),A),ASCOV)),kronecker(diag(p),t(A)))
   COV_W<-crossprod(t(tcrossprod(kronecker(t(W),diag(p)),ASCOV)),kronecker(W,diag(p)))
   
-  list(W=W,COV_W=COV_W,A=A,COV_A=COV_A)
+  list(W=W,COV_W=COV_W,A=A,COV_A=COV_A,EMD=EMD)
 }
 
 ASCOV_JADE_est <- function(X,mixed=TRUE)
